@@ -150,6 +150,16 @@ __all__ = (
     "TruckDimensionsTypeDef",
     "TruckWeightTypeDef",
     "UntagResourceRequestRequestTypeDef",
+    "UpdateGeofenceCollectionRequestRequestTypeDef",
+    "UpdateGeofenceCollectionResponseTypeDef",
+    "UpdateMapRequestRequestTypeDef",
+    "UpdateMapResponseTypeDef",
+    "UpdatePlaceIndexRequestRequestTypeDef",
+    "UpdatePlaceIndexResponseTypeDef",
+    "UpdateRouteCalculatorRequestRequestTypeDef",
+    "UpdateRouteCalculatorResponseTypeDef",
+    "UpdateTrackerRequestRequestTypeDef",
+    "UpdateTrackerResponseTypeDef",
 )
 
 AssociateTrackerConsumerRequestRequestTypeDef = TypedDict(
@@ -1531,3 +1541,168 @@ UntagResourceRequestRequestTypeDef = TypedDict(
         "TagKeys": List[str],
     },
 )
+
+_RequiredUpdateGeofenceCollectionRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateGeofenceCollectionRequestRequestTypeDef",
+    {
+        "CollectionName": str,
+    },
+)
+_OptionalUpdateGeofenceCollectionRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateGeofenceCollectionRequestRequestTypeDef",
+    {
+        "Description": str,
+        "PricingPlan": PricingPlanType,
+        "PricingPlanDataSource": str,
+    },
+    total=False,
+)
+
+
+class UpdateGeofenceCollectionRequestRequestTypeDef(
+    _RequiredUpdateGeofenceCollectionRequestRequestTypeDef,
+    _OptionalUpdateGeofenceCollectionRequestRequestTypeDef,
+):
+    pass
+
+
+UpdateGeofenceCollectionResponseTypeDef = TypedDict(
+    "UpdateGeofenceCollectionResponseTypeDef",
+    {
+        "CollectionArn": str,
+        "CollectionName": str,
+        "UpdateTime": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredUpdateMapRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateMapRequestRequestTypeDef",
+    {
+        "MapName": str,
+    },
+)
+_OptionalUpdateMapRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateMapRequestRequestTypeDef",
+    {
+        "Description": str,
+        "PricingPlan": PricingPlanType,
+    },
+    total=False,
+)
+
+
+class UpdateMapRequestRequestTypeDef(
+    _RequiredUpdateMapRequestRequestTypeDef, _OptionalUpdateMapRequestRequestTypeDef
+):
+    pass
+
+
+UpdateMapResponseTypeDef = TypedDict(
+    "UpdateMapResponseTypeDef",
+    {
+        "MapArn": str,
+        "MapName": str,
+        "UpdateTime": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredUpdatePlaceIndexRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdatePlaceIndexRequestRequestTypeDef",
+    {
+        "IndexName": str,
+    },
+)
+_OptionalUpdatePlaceIndexRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdatePlaceIndexRequestRequestTypeDef",
+    {
+        "DataSourceConfiguration": "DataSourceConfigurationTypeDef",
+        "Description": str,
+        "PricingPlan": PricingPlanType,
+    },
+    total=False,
+)
+
+
+class UpdatePlaceIndexRequestRequestTypeDef(
+    _RequiredUpdatePlaceIndexRequestRequestTypeDef, _OptionalUpdatePlaceIndexRequestRequestTypeDef
+):
+    pass
+
+
+UpdatePlaceIndexResponseTypeDef = TypedDict(
+    "UpdatePlaceIndexResponseTypeDef",
+    {
+        "IndexArn": str,
+        "IndexName": str,
+        "UpdateTime": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredUpdateRouteCalculatorRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateRouteCalculatorRequestRequestTypeDef",
+    {
+        "CalculatorName": str,
+    },
+)
+_OptionalUpdateRouteCalculatorRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateRouteCalculatorRequestRequestTypeDef",
+    {
+        "Description": str,
+        "PricingPlan": PricingPlanType,
+    },
+    total=False,
+)
+
+
+class UpdateRouteCalculatorRequestRequestTypeDef(
+    _RequiredUpdateRouteCalculatorRequestRequestTypeDef,
+    _OptionalUpdateRouteCalculatorRequestRequestTypeDef,
+):
+    pass
+
+
+UpdateRouteCalculatorResponseTypeDef = TypedDict(
+    "UpdateRouteCalculatorResponseTypeDef",
+    {
+        "CalculatorArn": str,
+        "CalculatorName": str,
+        "UpdateTime": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredUpdateTrackerRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateTrackerRequestRequestTypeDef",
+    {
+        "TrackerName": str,
+    },
+)
+_OptionalUpdateTrackerRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateTrackerRequestRequestTypeDef",
+    {
+        "Description": str,
+        "PricingPlan": PricingPlanType,
+        "PricingPlanDataSource": str,
+    },
+    total=False,
+)
+
+
+class UpdateTrackerRequestRequestTypeDef(
+    _RequiredUpdateTrackerRequestRequestTypeDef, _OptionalUpdateTrackerRequestRequestTypeDef
+):
+    pass
+
+
+UpdateTrackerResponseTypeDef = TypedDict(
+    "UpdateTrackerResponseTypeDef",
+    {
+        "TrackerArn": str,
+        "TrackerName": str,
+        "UpdateTime": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
